@@ -16,45 +16,41 @@
 
 #include "BrowserMessageArea.h"
 
-#include "statusbar/KJobProgressBar.h"
 #include "statusbar/LongMessageWidget.h"
-#include "statusbar/NetworkProgressBar.h"
 
 #define SHORT_MESSAGE_DURATION 5000
 #define POPUP_MESSAGE_DURATION 5000
 
 BrowserMessageArea::BrowserMessageArea( QWidget *parent )
-    : QFrame( parent )
+    : BoxWidget( true, parent )
     , m_busy( false )
 {
-    setObjectName( "BrowserMessageArea" );
-
-    setLayout( new QVBoxLayout( this ) );
+    setObjectName( QStringLiteral("BrowserMessageArea") );
 
     m_progressBar = new CompoundProgressBar( this );
-    connect( m_progressBar, SIGNAL(allDone()), this, SLOT(hideProgress()) );
+    connect( m_progressBar, &CompoundProgressBar::allDone, this, &BrowserMessageArea::hideProgress );
     layout()->addWidget( m_progressBar );
+
     m_progressBar->hide();
 
     m_messageLabel = new QLabel( this );
     m_messageLabel->setAlignment( Qt::AlignCenter );
     m_messageLabel->setWordWrap( true );
-    layout()->addWidget( m_messageLabel );
     m_messageLabel->hide();
 
     m_shortMessageTimer = new QTimer( this );
     m_shortMessageTimer->setSingleShot( true );
-    connect( m_shortMessageTimer, SIGNAL(timeout()), SLOT(nextShortMessage()) );
+    connect( m_shortMessageTimer, &QTimer::timeout, this, &BrowserMessageArea::nextShortMessage );
 
     //register to carry MessageType across threads
     qRegisterMetaType<Amarok::Logger::MessageType>( "MessageType" );
-    connect( this, SIGNAL(signalLongMessage(QString,MessageType)),
-             this, SLOT(slotLongMessage(QString,MessageType)),
+    connect( this, &BrowserMessageArea::signalLongMessage,
+             this, &BrowserMessageArea::slotLongMessage,
              Qt::QueuedConnection );
 }
 
 void
-BrowserMessageArea::shortMessage( const QString &text )
+BrowserMessageArea::shortMessageImpl( const QString &text )
 {
     if( !m_busy )
     {
@@ -70,23 +66,23 @@ BrowserMessageArea::shortMessage( const QString &text )
 }
 
 void
-BrowserMessageArea::longMessage( const QString &text, MessageType type )
+BrowserMessageArea::longMessageImpl( const QString &text, MessageType type )
 {
-    // The purpose of this emit is to make the operation thread safe. If this
-    // method is called from a non-GUI thread, the "emit" relays it over the
+    // The purpose of this Q_EMIT is to make the operation thread safe. If this
+    // method is called from a non-GUI thread, the "Q_EMIT" relays it over the
     // event loop to the GUI thread, so that we can safely create widgets.
-    emit signalLongMessage( text, type );
+    Q_EMIT signalLongMessage( text, type );
 }
 
 void
-BrowserMessageArea::newProgressOperation( KJob *job, const QString &text, QObject *obj,
-                                      const char *slot, Qt::ConnectionType type )
+BrowserMessageArea::newProgressOperationImpl( KJob *job, const QString &text, QObject *context,
+                                              const std::function<void ()> &function, Qt::ConnectionType type )
 {
-    KJobProgressBar *newBar = new KJobProgressBar( 0, job );
+    KJobProgressBar *newBar = new KJobProgressBar( nullptr, job );
     newBar->setDescription( text );
-    connect( job, SIGNAL(destroyed(QObject*)), m_progressBar,
-             SLOT(endProgressOperation(QObject*)) );
-    newBar->setAbortSlot( obj, slot, type );
+    connect( job, &KJob::destroyed, m_progressBar,
+             &CompoundProgressBar::endProgressOperation );
+    newBar->setAbortSlot( context, function, type );
     m_progressBar->addProgressBar( newBar, job );
     m_progressBar->show();
 
@@ -94,15 +90,15 @@ BrowserMessageArea::newProgressOperation( KJob *job, const QString &text, QObjec
 }
 
 void
-BrowserMessageArea::newProgressOperation( QNetworkReply *reply, const QString &text, QObject *obj,
-                                          const char *slot, Qt::ConnectionType type )
+BrowserMessageArea::newProgressOperationImpl( QNetworkReply *reply, const QString &text, QObject *obj,
+                                              const std::function<void ()> &function, Qt::ConnectionType type )
 {
-    NetworkProgressBar *newBar = new NetworkProgressBar( 0, reply );
+    NetworkProgressBar *newBar = new NetworkProgressBar( nullptr, reply );
     newBar->setDescription( text );
-    newBar->setAbortSlot( reply, SLOT(deleteLater()) );
-    connect( reply, SIGNAL(destroyed(QObject*)), m_progressBar,
-             SLOT(endProgressOperation(QObject*)) );
-    newBar->setAbortSlot( obj, slot, type );
+    newBar->setAbortSlot( reply, &QNetworkReply::deleteLater );
+    connect( reply, &QNetworkReply::destroyed, m_progressBar,
+             &CompoundProgressBar::endProgressOperation );
+    newBar->setAbortSlot( obj, function, type );
     m_progressBar->addProgressBar( newBar, reply );
     m_progressBar->show();
 
@@ -110,20 +106,23 @@ BrowserMessageArea::newProgressOperation( QNetworkReply *reply, const QString &t
 }
 
 void
-BrowserMessageArea::newProgressOperation( QObject *sender, const QString &text, int maximum,
-                                          QObject *obj, const char *slot, Qt::ConnectionType type )
+BrowserMessageArea::newProgressOperationImpl( QObject *sender, const QMetaMethod &increment, const QMetaMethod &end, const QString &text,
+                                              int maximum, QObject *obj, const std::function<void ()> &function, Qt::ConnectionType type )
 {
-    ProgressBar *newBar = new ProgressBar( 0 );
+    ProgressBar *newBar = new ProgressBar( nullptr );
     newBar->setDescription( text );
     newBar->setMaximum( maximum );
-    connect( sender, SIGNAL(destroyed(QObject*)), m_progressBar,
-             SLOT(endProgressOperation(QObject*)), Qt::QueuedConnection );
-    connect( sender, SIGNAL(endProgressOperation(QObject*)), m_progressBar,
-             SLOT(endProgressOperation(QObject*)), Qt::QueuedConnection );
-    connect( sender, SIGNAL(incrementProgress()), m_progressBar,
-             SLOT(slotIncrementProgress()), Qt::QueuedConnection );
-    connect( sender, SIGNAL(totalSteps(int)), newBar, SLOT(slotTotalSteps(int)) );
-    newBar->setAbortSlot( obj, slot, type );
+    connect( sender, &QObject::destroyed, m_progressBar,
+             &CompoundProgressBar::endProgressOperation, Qt::QueuedConnection );
+    int endIndex = m_progressBar->metaObject()->indexOfSlot( "endProgressOperation(QObject*)" );
+    auto endSlot = m_progressBar->metaObject()->method( endIndex );
+    connect( sender, end, m_progressBar, endSlot, Qt::QueuedConnection );
+    int incrementIndex = m_progressBar->metaObject()->indexOfSlot( "slotIncrementProgress()" );
+    auto incrementSlot = m_progressBar->metaObject()->method( incrementIndex );
+    connect( sender, increment, m_progressBar, incrementSlot, Qt::QueuedConnection );
+    if( sender->metaObject()->indexOfSignal( "totalSteps(int)" ) != -1 )
+        connect( sender, SIGNAL(totalSteps(int)), newBar, SLOT(slotTotalSteps(int)) );
+    newBar->setAbortSlot( obj, function, type );
     m_progressBar->addProgressBar( newBar, sender );
     m_progressBar->show();
 
@@ -156,15 +155,11 @@ BrowserMessageArea::nextShortMessage()
     }
 }
 
-void
-BrowserMessageArea::hideLongMessage()
-{
-    sender()->deleteLater();
-}
-
 void
 BrowserMessageArea::slotLongMessage( const QString &text, MessageType type )
 {
-    LongMessageWidget *message = new LongMessageWidget( this, text, type );
-    connect( message, SIGNAL(closed()), this, SLOT(hideLongMessage()) );
+    Q_UNUSED(type)
+
+    LongMessageWidget *message = new LongMessageWidget( text );
+    connect( message, &LongMessageWidget::closed, message, &QObject::deleteLater );
 }
