@@ -27,18 +27,16 @@
 #include "PlaylistsInFoldersProxy.h"
 #include "PlaylistsByProviderProxy.h"
 #include "PlaylistBrowserFilterProxy.h"
-#include "SvgHandler.h"
 #include "PlaylistBrowserView.h"
 #include "widgets/PrettyTreeDelegate.h"
 
 #include <KActionMenu>
-#include <KConfigGroup>
-#include <QIcon>
-#include <QStandardPaths>
 #include <KToolBar>
 
 #include <QHeaderView>
-#include <QToolBar>
+#include <QIcon>
+#include <QRegularExpression>
+#include <QStandardPaths>
 
 #include <typeinfo>
 
@@ -122,7 +120,7 @@ PlaylistBrowserCategory::PlaylistBrowserCategory( int playlistCategory,
     m_playlistView->setAcceptDrops( true );
     m_playlistView->setDropIndicatorShown( true );
 
-    foreach( const Playlists::PlaylistProvider *provider,
+    for( const Playlists::PlaylistProvider *provider :
              The::playlistManager()->providersForCategory( m_playlistCategory ) )
     {
         createProviderButton( provider );
@@ -144,22 +142,23 @@ PlaylistBrowserCategory::~PlaylistBrowserCategory()
 QString
 PlaylistBrowserCategory::filter() const
 {
-    return QUrl::toPercentEncoding( m_filterProxy->filterRegExp().pattern() );
+    return QString::fromLatin1( QUrl::toPercentEncoding( m_filterProxy->filterRegularExpression().pattern() ) );
 }
 
 void
 PlaylistBrowserCategory::setFilter( const QString &filter )
 {
     debug() << "Setting filter " << filter;
-    m_filterProxy->setFilterRegExp( QRegExp( QUrl::fromPercentEncoding( filter.toUtf8() ) ) );
+    m_filterProxy->setFilterRegularExpression( QRegularExpression( QUrl::fromPercentEncoding( filter.toUtf8() ) ) );
     //disable all other provider-buttons
-    foreach( QAction * const providerAction, m_providerActions )
+    for( QAction * const providerAction : m_providerActions )
     {
         const Playlists::PlaylistProvider *provider =
                 providerAction->data().value<const Playlists::PlaylistProvider *>();
         if( provider )
             providerAction->setChecked(
-                    m_filterProxy->filterRegExp().exactMatch( provider->prettyName() ) );
+                    QRegularExpression(QRegularExpression::anchoredPattern(m_filterProxy->filterRegularExpression().pattern()))
+                    .match( provider->prettyName() ).hasMatch());
     }
 }
 
@@ -255,13 +254,13 @@ PlaylistBrowserCategory::slotToggleProviderButton()
 {
     QString filter;
     QActionList checkedActions;
-    foreach( const Playlists::PlaylistProvider *p, m_providerActions.keys() )
+    for( const Playlists::PlaylistProvider *p : m_providerActions.keys() )
     {
         QAction *action = m_providerActions.value( p );
         if( action->isChecked() )
         {
-            QString escapedName = QRegExp::escape( p->prettyName() ).replace( ' ', QLatin1String("\\ ") );
-            filter += QString( filter.isEmpty() ? "%1" : "|%1" ).arg( escapedName );
+            QString escapedName = QRegularExpression::escape( p->prettyName() ).replace( QLatin1Char(' '), QLatin1String("\\ ") );
+            filter += QString( filter.isEmpty() ? QStringLiteral("%1") : QStringLiteral("|%1") ).arg( escapedName );
             checkedActions << action;
             action->setEnabled( true );
         }
@@ -270,7 +269,7 @@ PlaylistBrowserCategory::slotToggleProviderButton()
     if( checkedActions.count() == m_providerActions.count() )
         filter.clear();
 
-    m_filterProxy->setFilterRegExp( filter );
+    m_filterProxy->setFilterRegularExpression( filter );
 
     //don't allow the last visible provider to be hidden
     if( checkedActions.count() == 1 )
@@ -287,13 +286,13 @@ PlaylistBrowserCategory::createNewFolder()
     if( !folderIndices.isEmpty() )
     {
         int folderCount( 0 );
-        foreach( const QModelIndex &folder, folderIndices )
+        for( const QModelIndex &folder : folderIndices )
         {
-            QRegExp regex( name + " \\((\\d+)\\)" );
-            int matchIndex = regex.indexIn( folder.data( Qt::DisplayRole ).toString() );
-            if (matchIndex != -1)
+            QRegularExpression regex( name + QStringLiteral(" \\((\\d+)\\)") );
+            QRegularExpressionMatch rmatch = regex.match( folder.data( Qt::DisplayRole ).toString() );
+            if ( rmatch.hasMatch() )
             {
-                int newNumber = regex.cap( 1 ).toInt();
+                int newNumber = rmatch.captured( 1 ).toInt();
                 if (newNumber > folderCount)
                     folderCount = newNumber;
             }
