@@ -25,7 +25,6 @@
 #include "playlistmanager/PlaylistManager.h"
 #include "playlistmanager/SyncedPodcast.h"
 #include "PodcastCategory.h"
-#include "SvgHandler.h"
 #include "widgets/PrettyTreeRoles.h"
 
 #include <QAction>
@@ -96,7 +95,7 @@ PlaylistBrowserNS::PodcastModel::icon( const PodcastChannelPtr &channel ) const
 {
     QStringList emblems;
     //TODO: only check visible episodes. For now those are all returned by episodes().
-    foreach( const Podcasts::PodcastEpisodePtr ep, channel->episodes() )
+    for( const Podcasts::PodcastEpisodePtr &ep : channel->episodes() )
     {
         if( ep->isNew() )
         {
@@ -146,7 +145,7 @@ PlaylistBrowserNS::PodcastModel::icon( const PodcastChannelPtr &channel ) const
         return pixmap;
     }
     else
-        return ( QIcon(new KIconEngine( "podcast-amarok", KIconLoader::global(), emblems )).pixmap( 32, 32 ) );
+        return ( QIcon(new KIconEngine( QStringLiteral("podcast-amarok"), KIconLoader::global(), emblems )).pixmap( 32, 32 ) );
 }
 
 QVariant
@@ -157,9 +156,9 @@ PlaylistBrowserNS::PodcastModel::icon( const PodcastEpisodePtr &episode ) const
         emblems << QStringLiteral("go-down");
 
     if( episode->isNew() )
-        return ( QIcon( new KIconEngine( "rating", KIconLoader::global(), emblems )).pixmap( 24, 24 ) );
+        return ( QIcon( new KIconEngine( QStringLiteral("rating"), KIconLoader::global(), emblems )).pixmap( 24, 24 ) );
     else
-        return ( QIcon( new KIconEngine( "podcast-amarok", KIconLoader::global(), emblems )).pixmap( 24, 24 ));
+        return ( QIcon( new KIconEngine( QStringLiteral("podcast-amarok"), KIconLoader::global(), emblems )).pixmap( 24, 24 ));
 }
 
 QVariant
@@ -365,7 +364,7 @@ PlaylistBrowserNS::PodcastModel::addPodcast()
 void
 PlaylistBrowserNS::PodcastModel::refreshPodcasts()
 {
-    foreach( Playlists::PlaylistProvider *provider,
+    for( Playlists::PlaylistProvider *provider :
              The::playlistManager()->providersForCategory( PlaylistManager::PodcastChannel ) )
     {
         PodcastProvider *podcastProvider = dynamic_cast<PodcastProvider *>( provider );
@@ -390,7 +389,7 @@ Meta::TrackList
 PlaylistBrowserNS::PodcastModel::podcastEpisodesToTracks( Podcasts::PodcastEpisodeList episodes )
 {
     Meta::TrackList tracks;
-    foreach( Podcasts::PodcastEpisodePtr episode, episodes )
+    for( Podcasts::PodcastEpisodePtr episode : episodes )
         tracks << Meta::TrackPtr::staticCast( episode );
     return tracks;
 }
