@@ -24,7 +24,7 @@
 #include "core/capabilities/CollectionScanCapability.h"
 #include "core/capabilities/CollectionImportCapability.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QMutex>
 
@@ -37,7 +37,6 @@ class GenericScanManager;
 namespace Collections {
 
 class CollectionLocation;
-class DatabaseCollectionLocationFactory;
 
 /** The DatabaseCollection is intended to be a base class for all database backed primary collections.
  *  Primary collection implies that the basis for the collection is a file system.
@@ -59,14 +58,13 @@ class DatabaseCollection : public Collections::Collection
 
     public:
         /** Creates a new DatabaseCollection.
-         *  @param storage The storage this collection should work on. It will be freed by the collection.
          */
         DatabaseCollection();
-        virtual ~DatabaseCollection();
+        ~DatabaseCollection() override;
 
-        virtual QString collectionId() const;
-        virtual QString prettyName() const;
-        virtual KIcon icon() const;
+        QString collectionId() const override;
+        QString prettyName() const override;
+        QIcon icon() const override;
 
         virtual GenericScanManager *scanManager() const;
         virtual MountPointManager *mountPointManager() const;
@@ -96,19 +94,19 @@ class DatabaseCollection : public Collections::Collection
          */
         void collectionUpdated();
 
-        virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
-        virtual Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type );
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
+        Capabilities::Capability* createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
-    public slots:
+    public Q_SLOTS:
         /** Dumps the complete database content.
          *  The content of all Amarok tables is dumped in a couple of files
          *  in the users homedirectory.
          */
         virtual void dumpDatabaseContent() = 0;
 
-    protected slots:
-        virtual void slotDeviceAdded( int id ) { Q_UNUSED( id ); };
-        virtual void slotDeviceRemoved( int id ) { Q_UNUSED( id ); };
+    protected Q_SLOTS:
+        virtual void slotDeviceAdded( int id ) { Q_UNUSED( id ); }
+        virtual void slotDeviceRemoved( int id ) { Q_UNUSED( id ); }
 
     protected:
         MountPointManager *m_mpm;
@@ -124,12 +122,12 @@ class DatabaseCollectionScanCapability : public Capabilities::CollectionScanCapa
     Q_OBJECT
     public:
 
-        DatabaseCollectionScanCapability( DatabaseCollection* collection );
-        virtual ~DatabaseCollectionScanCapability();
+        explicit DatabaseCollectionScanCapability( DatabaseCollection* collection );
+        ~DatabaseCollectionScanCapability() override;
 
-        virtual void startFullScan();
-        virtual void startIncrementalScan( const QString &directory = QString() );
-        virtual void stopScan();
+        void startFullScan() override;
+        void startIncrementalScan( const QString &directory = QString() ) override;
+        void stopScan() override;
 
     private:
         DatabaseCollection* m_collection;
@@ -140,10 +138,10 @@ class DatabaseCollectionImportCapability : public Capabilities::CollectionImport
     Q_OBJECT
     public:
 
-        DatabaseCollectionImportCapability( DatabaseCollection* collection );
-        virtual ~DatabaseCollectionImportCapability();
+        explicit DatabaseCollectionImportCapability( DatabaseCollection* collection );
+        ~DatabaseCollectionImportCapability() override;
 
-        virtual void import( QIODevice *input, QObject *listener );
+        void import( QIODevice *input, QObject *listener ) override;
 
     private:
         DatabaseCollection* m_collection;
