@@ -874,7 +874,7 @@ SqlTrack::commitIfInNonBatchUpdate()
             m_album->setSuppressImageAutoFetch( true );
 
             if( m_album->hasAlbumArtist() &&
-                m_album->albumArtist() == oldArtist &&
+                m_album->albumArtist() == Meta::ArtistPtr::dynamicCast(oldArtist) &&
                 !m_cache.contains( Meta::valAlbum ) &&
                 !m_cache.contains( Meta::valAlbumId ) )
             {
@@ -920,8 +920,8 @@ SqlTrack::commitIfInNonBatchUpdate()
             m_cache.remove( Meta::valAlbum );
             m_cache.remove( Meta::valAlbumId );
             m_cache.remove( Meta::valAlbumArtist );
-            oldAlbum.clear();
-            newAlbum.clear();
+            oldAlbum.reset();
+            newAlbum.reset();
         }
     }
 
@@ -1635,7 +1635,7 @@ SqlAlbum::image( int size ) const
 }
 
 QUrl
-SqlAlbum::imageLocation( int size )
+SqlAlbum::imageLocation( int size ) const
 {
     if( !hasImage() )
         return QUrl();
