@@ -192,7 +192,7 @@ namespace Meta
             TrackList tracks() override;
             bool hasImage( int size = 0 ) const override;
             QImage image( int size = 0 ) const override;
-            QUrl imageLocation( int size = 0 ) override;
+            QUrl imageLocation( int size = 0 ) const override;
             bool canUpdateImage() const override;
             void setImage( const QImage &image ) override;
             void removeImage() override;
