@@ -31,13 +31,13 @@ namespace Capabilities
      * @author Ralf Engels <ralf-engels@gmx.de>
      */
 
-    class AMAROK_CORE_EXPORT CollectionImportCapability : public Capabilities::Capability
+    class AMAROKCORE_EXPORT CollectionImportCapability : public Capabilities::Capability
     {
         Q_OBJECT
         public:
 
             CollectionImportCapability();
-            virtual ~CollectionImportCapability();
+            ~CollectionImportCapability() override;
 
             /** Starts importing the given file into the collection.
                 @param input is an already opened input device. The importer will take ownership.
