@@ -65,7 +65,7 @@ CoverFetcher::CoverFetcher()
     : QObject()
 {
     DEBUG_BLOCK
-    setObjectName( "CoverFetcher" );
+    setObjectName( QStringLiteral("CoverFetcher") );
     qRegisterMetaType<CoverFetchUnit::Ptr>("CoverFetchUnit::Ptr");
 
     s_instance = this;
@@ -94,7 +94,7 @@ CoverFetcher::manualFetch( Meta::AlbumPtr album )
 {
     debug() << QStringLiteral("Adding interactive cover fetch for: '%1' from %2")
         .arg( album->name(),
-              Amarok::config("Cover Fetcher").readEntry("Interactive Image Source", "LastFm") );
+              Amarok::config(QStringLiteral("Cover Fetcher")).readEntry("Interactive Image Source", "LastFm") );
     switch( fetchSource() )
     {
     case CoverFetch::LastFm:
@@ -121,7 +121,7 @@ CoverFetcher::queueAlbum( Meta::AlbumPtr album )
 void
 CoverFetcher::queueAlbums( Meta::AlbumList albums )
 {
-    foreach( Meta::AlbumPtr album, albums )
+    for( Meta::AlbumPtr album : albums )
     {
         QTimer::singleShot( 0, m_queue, [=] () { m_queue->add( album, CoverFetch::Automatic ); } );
     }
@@ -131,7 +131,7 @@ void
 CoverFetcher::queueQuery( const Meta::AlbumPtr &album, const QString &query, int page )
 {
     QTimer::singleShot( 0, m_queue, [=] () { m_queue->addQuery( query, fetchSource(), page, album ); } );
-    debug() << QString( "Queueing cover fetch query: '%1' (page %2)" ).arg( query, QString::number( page ) );
+    debug() << QStringLiteral( "Queueing cover fetch query: '%1' (page %2)" ).arg( query, QString::number( page ) );
 }
 
 void
@@ -139,7 +139,7 @@ CoverFetcher::queueQueryForAlbum( Meta::AlbumPtr album )
 {
     QString query( album->name() );
     if( album->hasAlbumArtist() )
-        query += ' ' + album->albumArtist()->name();
+        query += QLatin1Char(' ') + album->albumArtist()->name();
     queueQuery( album, query, 1 );
 }
 
@@ -164,7 +164,7 @@ CoverFetcher::slotFetch( CoverFetchUnit::Ptr unit )
     }
 
     // Was with uniqueKeys, however the payload urls are ever operated only with insert, so there can't be duplicates
-    foreach( const QUrl &url, urls.keys() )
+    for( const QUrl &url : urls.keys() )
     {
         if( !url.isValid() )
             continue;
@@ -306,7 +306,7 @@ CoverFetcher::slotDialogFinished()
      * if there are still covers yet to be retrieved.
      */
     QList< CoverFetchUnit::Ptr > units = m_urls.values();
-    foreach( const CoverFetchUnit::Ptr &unit, units )
+    for( const CoverFetchUnit::Ptr &unit : units )
     {
         if( unit->isInteractive() )
             abortFetch( unit );
@@ -390,7 +390,7 @@ CoverFetcher::abortFetch( const CoverFetchUnit::Ptr &unit )
     QTimer::singleShot( 0, m_queue, [=] () {  m_queue->remove( unit ); } );
     m_selectedImages.remove( unit );
     QList<QUrl> urls = m_urls.keys( unit );
-    foreach( const QUrl &url, urls )
+    for( const QUrl &url : urls )
         m_urls.remove( url );
     The::networkAccessManager()->abortGet( urls );
 }
@@ -426,7 +426,7 @@ CoverFetcher::finish( const CoverFetchUnit::Ptr &unit,
             Amarok::Logger::shortMessage( text );
             QString debugMessage;
             if( !message.isEmpty() )
-                debugMessage = '[' + message + ']';
+                debugMessage = QLatin1Char('[') + message + QLatin1Char(']');
             debug() << "Finished with errors for album" << albumName << debugMessage;
         }
         m_errors += message;
@@ -461,12 +461,12 @@ CoverFetcher::finish( const CoverFetchUnit::Ptr &unit,
 CoverFetch::Source
 CoverFetcher::fetchSource() const
 {
-    const KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    const KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     const QString sourceEntry = config.readEntry( "Interactive Image Source", "LastFm" );
     CoverFetch::Source source;
-    if( sourceEntry == "LastFm" )
+    if( sourceEntry == QStringLiteral("LastFm") )
         source = CoverFetch::LastFm;
-    else if( sourceEntry == "Google" )
+    else if( sourceEntry == QStringLiteral("Google") )
         source = CoverFetch::Google;
     else
         source = CoverFetch::Discogs;
