@@ -41,18 +41,18 @@ class AMAROK_EXPORT DynamicPlaylist : public QObject
     Q_OBJECT
 
     public:
-        DynamicPlaylist( QObject *parent = 0 );
-        DynamicPlaylist( QXmlStreamReader *reader, QObject *parent = 0 );
-        virtual ~DynamicPlaylist();
+        explicit DynamicPlaylist( QObject *parent = nullptr );
+        explicit DynamicPlaylist( QXmlStreamReader *reader, QObject *parent = nullptr );
+        ~DynamicPlaylist() override;
 
         virtual void toXml( QXmlStreamWriter *writer ) const = 0;
 
         virtual void requestTracks(int) = 0;
 
         QString title() const;
-        void setTitle( QString );
+        void setTitle( const QString &);
 
-    signals:
+    Q_SIGNALS:
         void tracksReady( Meta::TrackList );
 
         /** Emitted when this playlist has been modified in some way.
@@ -61,7 +61,7 @@ class AMAROK_EXPORT DynamicPlaylist : public QObject
         void changed( Dynamic::DynamicPlaylist* playlist );
 
 
-    public slots:
+    public Q_SLOTS:
         /** Start recalculating all tracks after the currently played track */
         // virtual void repopulate();
 
