@@ -56,7 +56,7 @@ namespace Dynamic
     class AMAROK_EXPORT TrackCollection : public QSharedData
     {
         public:
-            TrackCollection( const QStringList& uids );
+            explicit TrackCollection( const QStringList& uids );
 
             int count() const;
             QStringList uids() const;
@@ -86,9 +86,10 @@ namespace Dynamic
             TrackSet( const TrackSet& other );
 
             /** Creates a TrackSet that represents the whole universe.
-                @param value If true set is set to "full". Else to "empty".
+             *  @param collection The collection of the tracks
+             *  @param value If true set is set to "full". Else to "empty".
             */
-            TrackSet( const Dynamic::TrackCollectionPtr collection, bool value );
+            TrackSet( const Dynamic::TrackCollectionPtr &collection, bool value );
 
             /** Includes or excludes all tracks in the set.
                 @param value If true set is set to "full". Else to "empty".
