@@ -72,8 +72,8 @@ Dynamic::QuizPlayBias::fromXml( QXmlStreamReader *reader )
 
         if( reader->isStartElement() )
         {
-            QStringRef name = reader->name();
-            if( name == "follow" )
+            QStringView name = reader->name();
+            if( name == QStringLiteral("follow") )
                 m_follow = followForName( reader->readElementText(QXmlStreamReader::SkipChildElements) );
             else
             {
@@ -311,11 +311,11 @@ Dynamic::QuizPlayBias::lastChar( const QString &str )
     int endIndex = str.length();
     int index;
 
-    index = str.indexOf( '[' );
+    index = str.indexOf( QLatin1Char('[') );
     if( index > 0 && index < endIndex )
         endIndex = index;
 
-    index = str.indexOf( '(' );
+    index = str.indexOf( QLatin1Char('(') );
     if( index > 0 && index < endIndex )
         endIndex = index;
 
