@@ -35,7 +35,6 @@ ImporterSqlConnection::ImporterSqlConnection( const QString &driver,
                                               const QString &user,
                                               const QString &password )
     : m_connectionName( QUuid::createUuid().toString() )
-    , m_apiMutex( QMutex::Recursive )
     , m_openTransaction( false )
 {
     QSqlDatabase db = QSqlDatabase::addDatabase( driver, m_connectionName );
@@ -48,7 +47,6 @@ ImporterSqlConnection::ImporterSqlConnection( const QString &driver,
 
 ImporterSqlConnection::ImporterSqlConnection( const QString &dbPath )
     : m_connectionName( QUuid::createUuid().toString() )
-    , m_apiMutex( QMutex::Recursive )
     , m_openTransaction( false )
 {
     QSqlDatabase db = QSqlDatabase::addDatabase( QStringLiteral("QSQLITE"), m_connectionName );
@@ -57,7 +55,6 @@ ImporterSqlConnection::ImporterSqlConnection( const QString &dbPath )
 
 ImporterSqlConnection::ImporterSqlConnection()
     : m_connectionName( QUuid::createUuid().toString() )
-    , m_apiMutex( QMutex::Recursive )
     , m_openTransaction( false )
 {
 }
@@ -155,7 +152,7 @@ ImporterSqlConnection::slotQuery( const QString &query, const QVariantMap &bindV
 {
     Q_ASSERT( this->thread() == ThreadWeaver::Thread::currentThread() );
 
-    if( ok != 0 )
+    if( ok != nullptr )
         *ok = false;
 
     QSqlDatabase db = connection();
@@ -171,7 +168,7 @@ ImporterSqlConnection::slotQuery( const QString &query, const QVariantMap &bindV
 
     if( q.exec() )
     {
-        if( ok != 0 )
+        if( ok != nullptr )
             *ok = true;
 
         m_result.reserve( q.size() );
