@@ -24,10 +24,9 @@
 
 #include "amarok_export.h"
 
+#include <QObject>
 #include <QPointer>
-
-#include <phonon/Path>
-#include <phonon/Effect>
+#include <gst/gst.h>
 
 static const int s_equalizerBandsNum = 10; // Number of equalizer parameters excluding Preamp
 
@@ -40,14 +39,8 @@ public:
     explicit EqualizerController( QObject *object );
     ~EqualizerController() override;
 
-    void initialize( const Phonon::Path &path );
+    void setEqElement( GstElement *eqElement);
 
-    /**
-     * Phonon equalizer support is required for Amarok to enable equalizer
-     * this method return whatever phonon support equalizer effect.
-     *
-     * @return @c true if the phonon support equalizer effect, @c false otherwise
-     */
     bool isEqSupported() const;
 
     /**
@@ -115,8 +108,7 @@ Q_SIGNALS:
     void presetsChanged( const QString &name );
 
 private:
-    QPointer<Phonon::Effect>            m_equalizer;
-    Phonon::Path                            m_path;
+    GstElement *m_equalizer; //built during pipeline init
 };
 
 #endif
