@@ -38,50 +38,50 @@ public:
     /**
      * Constructor.
      */
-    explicit ProxyBase( AbstractModel *belowModel, QObject *parent = 0 );
+    explicit ProxyBase( AbstractModel *belowModel, QObject *parent = nullptr );
 
     /**
      * Destructor.
      */
-    virtual ~ProxyBase();
+    ~ProxyBase() override;
 
     //! Inherited from Playlist::AbstractModel
-    QAbstractItemModel* qaim() const { return const_cast<ProxyBase*>( this ); }
+    QAbstractItemModel* qaim() const override { return const_cast<ProxyBase*>( this ); }
 
-    virtual quint64 activeId() const;
-    virtual int activeRow() const;
-    virtual Meta::TrackPtr activeTrack() const;
-    virtual QSet<int> allRowsForTrack( const Meta::TrackPtr track ) const;
-    virtual void clearSearchTerm();
-    virtual bool containsTrack( const Meta::TrackPtr track ) const;
-    virtual int currentSearchFields();
-    virtual QString currentSearchTerm();
-    virtual bool exportPlaylist( const QString &path, bool relative = false ) const;
-    virtual void filterUpdated();
-    virtual int find( const QString &searchTerm, int searchFields );
-    virtual int findNext( const QString &searchTerm, int selectedRow, int searchFields );
-    virtual int findPrevious( const QString &searchTerm, int selectedRow, int searchFields );
-    virtual int firstRowForTrack( const Meta::TrackPtr track ) const;
-    virtual quint64 idAt( const int row ) const;
-    virtual bool rowExists( int row ) const;
-    virtual int rowForId( const quint64 id ) const;
-    virtual int rowFromBottomModel( const int rowInBase );
-    virtual int rowToBottomModel( const int rowInProxy );
-    virtual void setActiveId( const quint64 id );
-    virtual void setActiveRow( int row );
-    virtual void setAllUnplayed();
-    virtual void emitQueueChanged();
-    virtual int queuePositionOfRow( int row );
-    virtual void showOnlyMatches( bool onlyMatches );
-    virtual Item::State stateOfId( quint64 id ) const;
-    virtual Item::State stateOfRow( int row ) const;
-    virtual qint64 totalLength() const;
-    virtual quint64 totalSize() const;
-    virtual Meta::TrackPtr trackAt( int row ) const;
-    virtual Meta::TrackPtr trackForId( const quint64 id ) const;
-    virtual Meta::TrackList tracks() const;
+    quint64 activeId() const override;
+    int activeRow() const override;
+    Meta::TrackPtr activeTrack() const override;
+    QSet<int> allRowsForTrack( const Meta::TrackPtr& track ) const override;
+    void clearSearchTerm() override;
+    bool containsTrack( const Meta::TrackPtr& track ) const override;
+    int currentSearchFields() override;
+    QString currentSearchTerm() override;
+    bool exportPlaylist( const QString &path, bool relative = false ) override;
+    void filterUpdated() override;
+    int find( const QString &searchTerm, int searchFields ) override;
+    int findNext( const QString &searchTerm, int selectedRow, int searchFields ) override;
+    int findPrevious( const QString &searchTerm, int selectedRow, int searchFields ) override;
+    int firstRowForTrack( const Meta::TrackPtr& track ) const override;
+    quint64 idAt( const int row ) const override;
+    bool rowExists( int row ) const override;
+    int rowForId( const quint64 id ) const override;
+    int rowFromBottomModel( const int rowInBase ) override;
+    int rowToBottomModel( const int rowInProxy ) override;
+    void setActiveId( const quint64 id ) override;
+    void setActiveRow( int row ) override;
+    void setAllUnplayed() override;
+    void emitQueueChanged() override;
+    int queuePositionOfRow( int row ) override;
+    void showOnlyMatches( bool onlyMatches ) override;
+    Item::State stateOfId( quint64 id ) const override;
+    Item::State stateOfRow( int row ) const override;
+    qint64 totalLength() const override;
+    quint64 totalSize() const override;
+    Meta::TrackPtr trackAt( int row ) const override;
+    Meta::TrackPtr trackForId( const quint64 id ) const override;
+    Meta::TrackList tracks() override;
 
-signals:
+Q_SIGNALS:
     //! Proxied from Playlist::Model.
     void activeTrackChanged( const quint64 );
     void queueChanged();
@@ -90,7 +90,7 @@ protected:
     /**
      * Check if a certain row in the source model matches a search term when looking at
      * the fields specified by the searchFields bitmask.
-     * @param row The row number in the source model to match against.
+     * @param sourceModelRow The row number in the source model to match against.
      * @param searchTerm The search term.
      * @param searchFields A bitmask containing the fields that should be matched against.
      * @return True if a match is found in any field, false otherwise.
@@ -99,7 +99,7 @@ protected:
 
     /**
      * Converts a row number in the underlying model to a row number in this proxy.
-     * @param rowInSource the row number that's valid in 'sourceModel()'.
+     * @param sourceModelRow the row number that's valid in 'sourceModel()'.
      * @return the row number that's valid in this proxy.
      */
     virtual int rowFromSource( int sourceModelRow ) const;
@@ -107,10 +107,10 @@ protected:
     /**
      * Converts a row number in this proxy to a row number in the underlying model.
      *
-     * As a special case, 'rowInProxy == rowCount()' returns the bottom model's
+     * As a special case, 'proxyModelRow == rowCount()' returns the bottom model's
      * 'rowCount()'. See comment at 'rowToBottomModel()'.
      *
-     * @param rowInProxy the row number that's valid in this proxy.
+     * @param proxyModelRow the row number that's valid in this proxy.
      * @return the row number that's valid in 'sourceModel()'.
      */
     virtual int rowToSource( int proxyModelRow ) const;
