@@ -95,15 +95,15 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     QMenuBar *bar = new QMenuBar( this );
     setMenuBar( bar );
     QToolBar *toolBar = new QToolBar( this );
-    QAction *action = new QAction( i18n( "Stop" ), this );
-    action->setIcon( QApplication::style()->standardIcon( QStyle::SP_MediaStop ) );
-    connect( action, &QAction::toggled, this, &ScriptConsole::slotAbortEvaluation );
-    toolBar->addAction( action );
-    action = new QAction( QIcon::fromTheme( QStringLiteral("media-playback-start") ), i18n("Execute Script"), this );
-    action->setShortcut( Qt::CTRL | Qt::Key_Enter );
-    connect( action, &QAction::triggered, this, &ScriptConsole::slotExecuteNewScript );
-    toolBar->addAction( action );
-    action = new QAction( QIcon::fromTheme( QStringLiteral("document-new") ), i18n( "&New Script" ), this );
+    m_stopAction = new QAction( i18n( "Stop" ), this );
+    m_stopAction->setIcon( QApplication::style()->standardIcon( QStyle::SP_MediaStop ) );
+    connect( m_stopAction, &QAction::toggled, this, &ScriptConsole::slotAbortEvaluation );
+    toolBar->addAction( m_stopAction );
+    m_startAction = new QAction( QIcon::fromTheme( QStringLiteral("media-playback-start") ), i18n("Execute Script"), this );
+    m_startAction->setShortcut( QKeyCombination( Qt::ControlModifier | Qt::ShiftModifier, Qt::Key_R ) );
+    connect( m_startAction, &QAction::triggered, this, &ScriptConsole::slotExecuteNewScript );
+    toolBar->addAction( m_startAction );
+    QAction *action = new QAction( QIcon::fromTheme( QStringLiteral("document-new") ), i18n( "&New Script" ), this );
     action->setShortcut( Qt::CTRL | Qt::Key_N );
     toolBar->addAction( action );
     connect( action, &QAction::triggered, this, &ScriptConsole::slotNewScript );
@@ -114,11 +114,9 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     toolBar->addAction( action );
     connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::clear );
     action = new QAction( i18n("Previous Script"), this );
-    action->setShortcut( QKeySequence::MoveToPreviousPage );
     connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::prev );
     toolBar->addAction( action );
     action = new QAction( i18n("Next Script"), this );
-    action->setShortcut( QKeySequence::MoveToNextPage );
     connect( action, &QAction::triggered, m_scriptListDock, &ScriptListDockWidget::next );
     toolBar->addAction( action );
 
@@ -138,12 +136,10 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     connect( m_scriptListDock, &ScriptListDockWidget::edit, this, &ScriptConsole::slotEditScript );
     connect( m_scriptListDock, &ScriptListDockWidget::currentItemChanged, this, &ScriptConsole::setCurrentScriptItem );
 
-    QListWidgetItem *item = new QListWidgetItem( QStringLiteral( "The Amarok Script Console allows you to easily execute"
-                                                "JavaScript with access to all functions\nand methods you would"
-                                                "have in an Amarok script.\nInformation on scripting for Amarok is"
-                                                "available at:\nhttp://community.kde.org/Amarok/Development#Scripting"
-                                                "\nExecute code: CTRL-Enter\nBack in code history: Page Up"
-                                                "\nForward in code history: Page Down")
+    QListWidgetItem *item = new QListWidgetItem( QStringLiteral( "The Amarok Script Console allows you to easily execute\n"
+                                                "JavaScript with access to all functions\nand methods you would "
+                                                "have in an Amarok script.\nInformation on scripting for Amarok is "
+                                                "available at:\nhttps://community.kde.org/Amarok/Development#Scripting")
                                                , nullptr );
     item->setFlags( Qt::NoItemFlags );
     m_scriptListDock->addItem( item );
@@ -157,7 +153,8 @@ ScriptConsole::ScriptConsole( QWidget *parent )
     if( m_savePath.isEmpty() )
         m_savePath = Amarok::saveLocation(QStringLiteral("scriptconsole"));
 
-    slotNewScript();
+    if( !loadScripts() )
+        slotNewScript();
     show();
     raise();
 
@@ -196,7 +193,16 @@ ScriptConsole::slotExecuteNewScript()
         return;
 
     m_scriptItem->document()->save();
+    m_scriptItem->document()->setReadWrite( false );
+    m_startAction->setDisabled( true );
+    m_stopAction->setDisabled( false );
     m_scriptItem->start( false );
+
+    // Currently running scripts is synchronous, so this doesn't have that much point, but
+    // it's nice to have it already here in case scripts start running async again some day
+    m_scriptItem->document()->setReadWrite( true );
+    m_startAction->setDisabled( false );
+    m_stopAction->setDisabled( true );
 }
 
 void
@@ -222,6 +228,39 @@ ScriptConsole::slotEditScript( ScriptConsoleItem *item )
     setCurrentScriptItem( item );
 }
 
+bool
+ScriptConsole::loadScripts()
+{
+    if( m_savePath.isEmpty() || !QDir( m_savePath ).exists() )
+        return false;
+    ScriptConsoleItem *scriptItem = nullptr;
+    const QStringList maybeExisting = QDir( m_savePath ).entryList( QStringList(), QDir::Dirs | QDir::NoDotAndDotDot | QDir::Writable, QDir::NoSort );
+    debug() << "Loading existing script console scripts, checking "<< maybeExisting.length() << "directories";
+    int i = 0;
+    for( const auto &dir : maybeExisting )
+    {
+        QString scriptPath = QStringLiteral( "%1%2/" ).arg( m_savePath, dir );
+        if( QDir( scriptPath ).entryList( QStringList( QStringLiteral("main.js") ), QDir::Files | QDir::Writable, QDir::NoSort ).length() == 1 )
+        {
+            i++;
+            ScriptEditorDocument *document = new ScriptEditorDocument( this, m_editor->createDocument( nullptr ) );
+            QFile scriptText = QFile( scriptPath + QStringLiteral("/main.js") );
+            scriptText.open( QIODevice::ReadOnly );
+            document->setText( QString::fromUtf8( scriptText.readAll() ) );
+            scriptText.close();
+            scriptItem = new ScriptConsoleItem( this, dir, QStringLiteral("Generic"), scriptPath, document );
+            m_scriptListDock->addScript( scriptItem );
+        }
+    }
+    debug() << "Loaded "<< i << "scripts";
+    if( scriptItem )
+    {
+        setCurrentScriptItem( scriptItem );
+        return true;
+    }
+    return false;
+}
+
 ScriptConsoleItem*
 ScriptConsole::createScriptItem( const QString &script )
 {
@@ -253,6 +292,8 @@ ScriptConsole::getScriptListDockWidget()
 
 ScriptConsole::~ScriptConsole()
 {
+    // avoid changing active script when all have already been deleted
+    disconnect( m_scriptListDock, &ScriptListDockWidget::currentItemChanged, this, &ScriptConsole::setCurrentScriptItem );
     //m_debugger->detach();
 }
 
@@ -294,6 +335,9 @@ void
 ScriptConsole::slotAbortEvaluation()
 {
     m_scriptItem->pause();
+    m_scriptItem->document()->setReadWrite( true );
+    m_startAction->setDisabled( false );
+    m_stopAction->setDisabled( true );
 }
 
 
@@ -331,17 +375,18 @@ ScriptConsole::setCurrentScriptItem( ScriptConsoleItem *item )
     m_errorWidget->setWidget( error );
     error->show();
 
-    /* TODO - install filters
     if( item->engine() && item->running() )
     {
         view->document()->setReadWrite( false );
+        m_startAction->setDisabled( true );
+        m_stopAction->setDisabled( false );
     }
     else
     {
         view->document()->setReadWrite( true );
-        view->installEventFilter( this );
+        m_startAction->setDisabled( false );
+        m_stopAction->setDisabled( true );
     }
-    */
 }
 
 void
@@ -417,7 +462,7 @@ ScriptListDockWidget::getScript( const QString &scriptName)
 void
 ScriptListDockWidget::removeCurrentScript()
 {
-    QListWidgetItem *item = m_scriptListWidget->takeItem( m_scriptListWidget->currentRow() );
+    QListWidgetItem *item = m_scriptListWidget->item( m_scriptListWidget->currentRow() );
     ScriptConsoleItem *scriptItem = qvariant_cast<ScriptConsoleItem*>( item->data( ScriptRole ) );
     switch( KMessageBox::warningTwoActionsCancel( this, i18n( "Remove script file from disk?" ), i18n( "Remove Script" ), KGuiItem(i18nc( "Confirm if script file should be removed", "Remove")),
         KGuiItem(i18nc( "Confirm if script file should be removed", "Don't remove") ) ) )
@@ -453,7 +498,10 @@ ScriptListDockWidget::clear()
     if( sender() && KMessageBox::warningContinueCancel( nullptr, i18n("Are you absolutely certain?") ) == KMessageBox::Cancel )
         return;
     for( int i = 0; i<m_scriptListWidget->count(); ++i )
-        qvariant_cast<ScriptConsoleItem*>( m_scriptListWidget->item( i )->data( ScriptRole ) )->deleteLater();
+    {
+        if( qvariant_cast<ScriptConsoleItem*>( m_scriptListWidget->item( i )->data( ScriptRole ) ) )
+            qvariant_cast<ScriptConsoleItem*>( m_scriptListWidget->item( i )->data( ScriptRole ) )->deleteLater();
+    }
     m_scriptListWidget->clear();
 
 }
