@@ -22,7 +22,6 @@
 #include "core/meta/Meta.h"
 #include "core-impl/collections/support/CollectionManager.h"
 
-#include <QApplication>
 #include <QCoreApplication>
 #include <QJSEngine>
 #include <QQmlEngine>
@@ -55,8 +54,8 @@ ScriptableBiasFactory::init( QJSEngine *engine )
 {
     TrackSetExporter::init( engine );
     QJSValue scriptObj = engine->newQObject( new ScriptableBiasFactoryWrapper( engine ) );
-    engine->globalObject().setProperty( QStringLiteral("BiasFactory"),  scriptObj.property("biasCtor") );
-    engine->globalObject().setProperty( QStringLiteral("GroupBiasFactory"), scriptObj.property("groupBiasCtor") );
+    engine->globalObject().setProperty( QStringLiteral("BiasFactory"),  scriptObj.property(QStringLiteral("biasCtor")) );
+    engine->globalObject().setProperty( QStringLiteral("GroupBiasFactory"), scriptObj.property(QStringLiteral("groupBiasCtor")) );
 }
 
 ScriptableBiasFactory::ScriptableBiasFactory( QJSEngine *engine, bool groupBias )
@@ -412,7 +411,7 @@ TrackSetExporterWrapper::trackSetConstructor( QJSValue arg0, QJSValue arg1 )
         {
             debug() << "In Meta::Tracklist TrackSet ctor";
             trackList = qjsvalue_cast<Meta::TrackList>( arg0 );
-            foreach( const Meta::TrackPtr &track, trackList )
+            for( const Meta::TrackPtr &track : trackList )
             {
                 if( track )
                     uidList << track->uidUrl();
@@ -444,7 +443,7 @@ TrackSetExporter::init( QJSEngine *engine )
         fromScriptValue( jsValue, trackSet );
         return trackSet;
     } );
-    engine->globalObject().setProperty( QStringLiteral("TrackSet"), engine->newQObject( new TrackSetExporterWrapper( engine ) ).property( "trackSetConstructor" ) );
+    engine->globalObject().setProperty( QStringLiteral("TrackSet"), engine->newQObject( new TrackSetExporterWrapper( engine ) ).property( QStringLiteral("trackSetConstructor") ) );
 }
 
 void
