@@ -89,7 +89,6 @@ LastFmTreeModel::slotAddFriends()
                 afriend->setAvatarUrl( avatarUrl );
 
             m_myFriends->appendChild( afriend );
-            appendUserStations( afriend, name );
         }
 
         endInsertRows();
@@ -188,16 +187,6 @@ LastFmTreeModel::slotAddTopArtists()
     Q_EMIT dataChanged( parent, parent );
 }
 
-void
-LastFmTreeModel::appendUserStations( LastFmTreeItem* item, const QString &user )
-{
-    // no need to call begin/endInsertRows() or dataChanged(), we're being called inside
-    // beginInsertRows().
-    LastFmTreeItem* personal = new LastFmTreeItem( mapTypeToUrl( LastFm::UserChildPersonal, user ),
-                                                   LastFm::UserChildPersonal, i18n( "Personal Radio" ), item );
-    item->appendChild( personal );
-}
-
 void
 LastFmTreeModel::prepareAvatar( QPixmap &avatar, int size )
 {
@@ -384,6 +373,19 @@ LastFmTreeModel::data( const QModelIndex &index, int role ) const
     if( role == LastFm::TypeRole )
         return i->type();
 
+    if( role == LastFm::UrlRole)
+    {
+        switch( i->type() )
+        {
+            case LastFm::FriendsChild:
+            case LastFm::MyTagsChild:
+            case LastFm::ArtistsChild:
+                return i->url();
+            default:
+                break;
+        }
+    }
+
     return QVariant();
 }
 
@@ -415,20 +417,6 @@ LastFmTreeModel::flags( const QModelIndex &index ) const
         break;
     }
 
-    switch( i->type() )
-    {
-    case UserChildPersonal:
-    case MyTagsChild:
-    case ArtistsChild:
-    case MyRecommendations:
-    case PersonalRadio:
-    case MixRadio:
-        flags |= Qt::ItemIsDragEnabled;
-
-    default:
-        break;
-    }
-
     return flags;
 }
 
@@ -487,9 +475,6 @@ void
 LastFmTreeModel::setupModelData( LastFmTreeItem *parent )
 {
     // no need to call beginInsertRows() here, this is only called from constructor
-    parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::MyRecommendations ), LastFm::MyRecommendations, parent ) );
-    parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::PersonalRadio ), LastFm::PersonalRadio, parent ) );
-    parent->appendChild( new LastFmTreeItem( mapTypeToUrl( LastFm::MixRadio ), LastFm::MixRadio, parent ) );
 
     m_myTopArtists = new LastFmTreeItem( LastFm::TopArtists, parent );
     parent->appendChild( m_myTopArtists );
@@ -508,20 +493,12 @@ LastFmTreeModel::mapTypeToUrl( LastFm::Type type, const QString &key )
     QString const encoded_username = QString::fromLatin1( QUrl::toPercentEncoding( m_user.name() ) );
     switch( type )
     {
-    case MyRecommendations:
-        return QStringLiteral("lastfm://user/") + encoded_username + QStringLiteral("/recommended");
-    case PersonalRadio:
-        return QStringLiteral("lastfm://user/") + encoded_username + QStringLiteral("/personal");
-    case MixRadio:
-        return QStringLiteral("lastfm://user/") + encoded_username + QStringLiteral("/mix");
     case MyTagsChild:
-        return QStringLiteral("lastfm://usertags/") + encoded_username + QStringLiteral("/") + QLatin1String( QUrl::toPercentEncoding( key ) );
+        return QStringLiteral("https://www.last.fm/user/") + encoded_username + QStringLiteral("/tags/") + QLatin1String( QUrl::toPercentEncoding( key ) );
     case FriendsChild:
-        return QStringLiteral("lastfm://user/") + QLatin1String( QUrl::toPercentEncoding( key ) ) + QStringLiteral("/personal");
+        return QStringLiteral("https://www.last.fm/user/") + QLatin1String( QUrl::toPercentEncoding( key ) );
     case ArtistsChild:
-        return QStringLiteral("lastfm://artist/") + QLatin1String( QUrl::toPercentEncoding( key ) ) + QStringLiteral("/similarartists");
-    case UserChildPersonal:
-        return QStringLiteral("lastfm://user/") + QLatin1String( QUrl::toPercentEncoding( key ) ) + QStringLiteral("/personal");
+        return QStringLiteral("https://www.last.fm/music/") + QLatin1String( QUrl::toPercentEncoding( key ) );
     default:
         return QStringLiteral("");
     }
