@@ -79,10 +79,10 @@ Dynamic::WeeklyTopBias::fromXml( QXmlStreamReader *reader )
 
         if( reader->isStartElement() )
         {
-            QStringRef name = reader->name();
-            if( name == "from" )
+            QStringView name = reader->name();
+            if( name == QStringLiteral("from") )
                 m_range.from = QDateTime::fromSecsSinceEpoch( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
-            else if( name == "to" )
+            else if( name == QStringLiteral("to") )
                 m_range.to = QDateTime::fromSecsSinceEpoch( reader->readElementText(QXmlStreamReader::SkipChildElements).toLong() );
             else
             {
@@ -100,14 +100,14 @@ Dynamic::WeeklyTopBias::fromXml( QXmlStreamReader *reader )
 void
 Dynamic::WeeklyTopBias::toXml( QXmlStreamWriter *writer ) const
 {
-    writer->writeTextElement( "from", QString::number( m_range.from.toSecsSinceEpoch() ) );
-    writer->writeTextElement( "to",   QString::number( m_range.to.toSecsSinceEpoch() ) );
+    writer->writeTextElement( QStringLiteral("from"), QString::number( m_range.from.toSecsSinceEpoch() ) );
+    writer->writeTextElement( QStringLiteral("to"),   QString::number( m_range.to.toSecsSinceEpoch() ) );
 }
 
 QString
 Dynamic::WeeklyTopBias::sName()
 {
-    return "lastfm_weeklytop";
+    return QStringLiteral("lastfm_weeklytop");
 }
 
 QString
@@ -181,7 +181,7 @@ Dynamic::WeeklyTopBias::trackMatches( int position,
     uint fromTime = m_range.from.toSecsSinceEpoch();
     uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
-    foreach( uint weekTime, m_weeklyFromTimes )
+    for( uint weekTime : m_weeklyFromTimes )
     {
         if( weekTime > fromTime && weekTime < toTime && lastWeekTime )
         {
@@ -224,7 +224,7 @@ Dynamic::WeeklyTopBias::newQuery()
     uint fromTime = m_range.from.toSecsSinceEpoch();
     uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
-    foreach( uint weekTime, m_weeklyFromTimes )
+    for( uint weekTime : m_weeklyFromTimes )
     {
         if( weekTime > fromTime && weekTime < toTime && lastWeekTime )
         {
@@ -253,7 +253,7 @@ Dynamic::WeeklyTopBias::newQuery()
 
     // - construct the query
     m_qm->beginOr();
-    foreach( const QString &artist, artists )
+    for( const QString &artist : artists )
     {
         // debug() << "adding artist to query:" << artist;
         m_qm->addFilter( Meta::valArtist, artist, true, true );
@@ -278,8 +278,8 @@ Dynamic::WeeklyTopBias::newWeeklyTimesQuery()
     DEBUG_BLOCK
 
     QMap< QString, QString > params;
-    params[ "method" ] = "user.getWeeklyChartList" ;
-    params[ "user" ] = lastfm::ws::Username;
+    params[ QStringLiteral("method") ] = QStringLiteral("user.getWeeklyChartList") ;
+    params[ QStringLiteral("user") ] = lastfm::ws::Username;
 
     m_weeklyTimesJob = lastfm::ws::get( params );
 
@@ -308,7 +308,7 @@ void Dynamic::WeeklyTopBias::newWeeklyArtistQuery()
     uint fromTime = m_range.from.toSecsSinceEpoch();
     uint toTime   = m_range.to.toSecsSinceEpoch();
     uint lastWeekTime = 0;
-    foreach( uint weekTime, m_weeklyFromTimes )
+    for( uint weekTime : m_weeklyFromTimes )
     {
         if( weekTime > fromTime && weekTime < toTime && lastWeekTime )
         {
@@ -323,10 +323,10 @@ void Dynamic::WeeklyTopBias::newWeeklyArtistQuery()
             else
             {
                 QMap< QString, QString > params;
-                params[ "method" ] = "user.getWeeklyArtistChart";
-                params[ "user" ] = lastfm::ws::Username;
-                params[ "from" ] = QString::number( lastWeekTime );
-                params[ "to" ] = QString::number( m_weeklyToTimes[m_weeklyFromTimes.indexOf(lastWeekTime)] );
+                params[ QStringLiteral("method") ] = QStringLiteral("user.getWeeklyArtistChart");
+                params[ QStringLiteral("user") ] = lastfm::ws::Username;
+                params[ QStringLiteral("from") ] = QString::number( lastWeekTime );
+                params[ QStringLiteral("to") ] = QString::number( m_weeklyToTimes[m_weeklyFromTimes.indexOf(lastWeekTime)] );
 
                 QNetworkReply* reply = lastfm::ws::get( params );
                 connect( reply, &QNetworkReply::finished,
@@ -362,15 +362,15 @@ Dynamic::WeeklyTopBias::weeklyArtistQueryFinished()
     {
         // debug() << "got response:" << lfm;
         QStringList artists;
-        for( int i = 0; i < lfm[ "weeklyartistchart" ].children( "artist" ).size(); i++ )
+        for( int i = 0; i < lfm[ QStringLiteral("weeklyartistchart") ].children( QStringLiteral("artist") ).size(); i++ )
         {
             if( i == 12 ) // only up to 12 artist.
                 break;
-            lastfm::XmlQuery artist = lfm[ "weeklyartistchart" ].children( "artist" ).at( i );
-            artists.append( artist[ "name" ].text() );
+            lastfm::XmlQuery artist = lfm[ QStringLiteral("weeklyartistchart") ].children( QStringLiteral("artist") ).at( i );
+            artists.append( artist[ QStringLiteral("name") ].text() );
         }
 
-        uint week = QDomElement( lfm[ "weeklyartistchart" ] ).attribute( "from" ).toUInt();
+        uint week = QDomElement( lfm[ QStringLiteral("weeklyartistchart") ] ).attribute( QStringLiteral("from") ).toUInt();
         m_weeklyArtistMap.insert( week, artists );
         debug() << "got artists:" << artists << week;
 
@@ -409,7 +409,7 @@ Dynamic::WeeklyTopBias::weeklyTimesQueryFinished() // SLOT
         return;
     }
 
-    QDomNodeList nodes = doc.elementsByTagName( "chart" );
+    QDomNodeList nodes = doc.elementsByTagName( QStringLiteral("chart") );
     if( nodes.count() == 0 )
     {
         debug() << "USER has no history! can't do this!";
@@ -419,12 +419,12 @@ Dynamic::WeeklyTopBias::weeklyTimesQueryFinished() // SLOT
     for( int i = 0; i < nodes.size(); i++ )
     {
         QDomNode n = nodes.at( i );
-        m_weeklyFromTimes.append( n.attributes().namedItem( "from" ).nodeValue().toUInt() );
-        m_weeklyToTimes.append( n.attributes().namedItem( "to" ).nodeValue().toUInt() );
+        m_weeklyFromTimes.append( n.attributes().namedItem( QStringLiteral("from") ).nodeValue().toUInt() );
+        m_weeklyToTimes.append( n.attributes().namedItem( QStringLiteral("to") ).nodeValue().toUInt() );
 
         // debug() << "weeklyTimesResult"<<i<<":"<<m_weeklyFromTimes.last()<<"to"<<m_weeklyToTimes.last();
-        m_weeklyFromTimes.append( n.attributes().namedItem( "from" ).nodeValue().toUInt() );
-        m_weeklyToTimes.append( n.attributes().namedItem( "to" ).nodeValue().toUInt() );
+        m_weeklyFromTimes.append( n.attributes().namedItem( QStringLiteral("from") ).nodeValue().toUInt() );
+        m_weeklyToTimes.append( n.attributes().namedItem( QStringLiteral("to") ).nodeValue().toUInt() );
     }
 
     m_weeklyTimesJob->deleteLater();
@@ -441,7 +441,7 @@ Dynamic::WeeklyTopBias::fromDateChanged( const QDateTime& d ) // SLOT
 
     m_range.from = d;
     invalidate();
-    emit changed( BiasPtr( this ) );
+    Q_EMIT changed( BiasPtr( this ) );
 }
 
 
@@ -453,20 +453,20 @@ Dynamic::WeeklyTopBias::toDateChanged( const QDateTime& d ) // SLOT
 
     m_range.to = d;
     invalidate();
-    emit changed( BiasPtr( this ) );
+    Q_EMIT changed( BiasPtr( this ) );
 }
 
 
 void
 Dynamic::WeeklyTopBias::loadFromFile()
 {
-    QFile file( Amarok::saveLocation() + "dynamic_lastfm_topweeklyartists.xml" );
+    QFile file( Amarok::saveLocation() + QStringLiteral("dynamic_lastfm_topweeklyartists.xml") );
     file.open( QIODevice::ReadOnly | QIODevice::Text );
     QTextStream in( &file );
     while( !in.atEnd() )
     {
         QString line = in.readLine();
-        m_weeklyArtistMap.insert( line.split( '#' )[ 0 ].toUInt(), line.split( '#' )[ 1 ].split( '^' )  );
+        m_weeklyArtistMap.insert( line.split( QLatin1Char('#') )[ 0 ].toUInt(), line.split( QLatin1Char('#') )[ 1 ].split( QLatin1Char('^') )  );
     }
     file.close();
 }
@@ -475,12 +475,12 @@ Dynamic::WeeklyTopBias::loadFromFile()
 void
 Dynamic::WeeklyTopBias::saveDataToFile() const
 {
-    QFile file( Amarok::saveLocation() + "dynamic_lastfm_topweeklyartists.xml" );
+    QFile file( Amarok::saveLocation() + QStringLiteral("dynamic_lastfm_topweeklyartists.xml") );
     file.open( QIODevice::Truncate | QIODevice::WriteOnly | QIODevice::Text );
     QTextStream out( &file );
-    foreach( uint key, m_weeklyArtistMap.keys() )
+    for( uint key : m_weeklyArtistMap.keys() )
     {
-        out << key << "#" << m_weeklyArtistMap[ key ].join( "^" ) << Qt::endl;
+        out << key << "#" << m_weeklyArtistMap[ key ].join( QStringLiteral("^") ) << Qt::endl;
     }
     file.close();
 
