@@ -23,11 +23,11 @@
 #include "MagnatuneDatabaseHandler.h"
 #include "MagnatuneConfig.h"
 
+#include <KIO/StoredTransferJob>
 #include <KMessageBox>
 
 #include <QDir>
 #include <QFile>
-#include <QTemporaryDir>
 #include <QTextStream>
 
 using namespace Meta;
@@ -70,11 +70,11 @@ void MagnatuneDownloadHandler::membershipDownload( int membershipType, const QSt
 {
     QString type;
     if( membershipType == MagnatuneConfig::STREAM )
-        type = "stream";
+        type = QStringLiteral("stream");
     else
-         type = "download";
+         type = QStringLiteral("download");
     
-    QUrl purchaseURL = QUrl::fromUserInput( "http://" + username + ":" + password + "@" + type + ".magnatune.com/buy/membership_free_dl_xml?sku=" + m_currentAlbum->albumCode() + "&id=amarok" );
+    QUrl purchaseURL = QUrl::fromUserInput( QStringLiteral("http://") + username + QStringLiteral(":") + password + QStringLiteral("@") + type + QStringLiteral(".magnatune.com/buy/membership_free_dl_xml?sku=") + m_currentAlbum->albumCode() + QStringLiteral("&id=amarok") );
 
     m_membershipDownload = true;
 
@@ -101,7 +101,7 @@ void MagnatuneDownloadHandler::xmlDownloadComplete( KJob * downloadJob )
     }
 
     KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( downloadJob );
-    QString resultXml = QString( storedJob->data() );
+    QByteArray resultXml = storedJob->data();
 
     debug() << Qt::endl << Qt::endl << "result: " << resultXml;
 
@@ -123,7 +123,7 @@ void MagnatuneDownloadHandler::xmlDownloadComplete( KJob * downloadJob )
 
 
     MagnatuneDownloadInfo downloadInfo;
-    if ( downloadInfo.initFromString( resultXml, m_membershipDownload ) )
+    if ( downloadInfo.initFromString( QLatin1String(resultXml), m_membershipDownload ) )
     {
 
         downloadInfo.setAlbumCode( m_currentAlbum->albumCode() );
@@ -156,22 +156,22 @@ void MagnatuneDownloadHandler::setParent( QWidget * parent )
 
 }
 
-void MagnatuneDownloadHandler::saveDownloadInfo( const QString &infoXml )
+void MagnatuneDownloadHandler::saveDownloadInfo( const QByteArray &infoXml )
 {
 
     MagnatuneDatabaseHandler dbHandler;
 
-    QDir purchaseDir( Amarok::saveLocation( "magnatune.com/purchases/" ) );
+    QDir purchaseDir( Amarok::saveLocation( QStringLiteral("magnatune.com/purchases/") ) );
 
     debug() << "magnatune save location" << purchaseDir.absolutePath();
 
     //if directory does not exist, create it
     if ( ! purchaseDir.exists () )
     {
-        purchaseDir.mkdir( "." );
+        purchaseDir.mkdir( QStringLiteral(".") );
     }
 
-    QString fileName = m_currentAlbum->albumArtist()->name() + " - " + m_currentAlbum->name();
+    QString fileName = m_currentAlbum->albumArtist()->name() + QStringLiteral(" - ") + m_currentAlbum->name();
 
     QFile file( purchaseDir.absolutePath() + QLatin1Char('/') + fileName );
 
