@@ -22,7 +22,7 @@
 namespace Collections {
 
 /**
-A simple ServiceSqlCollection subclass for providing a magnatune membership specific implementaion of trackForUrl
+A simple ServiceSqlCollection subclass for providing a magnatune membership specific implementation of trackForUrl
 
 	@author Nikolaj Hald Nielsen <nhn@kde.org>
 */
@@ -32,9 +32,9 @@ public:
 
     MagnatuneSqlCollection( const QString &id, const QString &prettyName, ServiceMetaFactory * metaFactory, ServiceSqlRegistry * registry );
     
-    virtual Meta::TrackPtr trackForUrl( const KUrl &url );
+    Meta::TrackPtr trackForUrl( const QUrl &url ) override;
 
-    virtual CollectionLocation* location();
+    CollectionLocation* location() override;
 
 };
 
