@@ -19,8 +19,8 @@
 
 #include "Mp3tunesHarmonyDownload.h"
 #include "Mp3tunesHarmonyClient.h"
-#include <QCoreApplication>
 
+#include <QCoreApplication>
 #include <QObject>
 #include <QString>
 
@@ -36,14 +36,14 @@ extern "C" {
 }
 
 /**
- * A daemon that receives notfications from mp3tunes'
+ * A daemon that receives notifications from mp3tunes'
  * servers about new/changed tracks that can be synced.
  *
  * Because this classes implements libmp3tunes which uses
  * GLIB's c-style callbacks, all the callbacks must be static.
  * This requires some black magic on my part to keep the OO
  * facade intact. The solution is a global variable: theDaemon
- * delcared after this class. Your code must #define DEFINE_HARMONY
+ * declared after this class. Your code must \#define DEFINE_HARMONY
  * and instantiate a new Mp3tunesHarmonyDaemon for theDaemon.
  * @author Casey Link <unnamedrambler@gmail.com>
  */
@@ -56,15 +56,15 @@ class Mp3tunesHarmonyDaemon : public QCoreApplication
     /**
      * For the first time run, before we have an email and pin to authenticate
      */
-    Mp3tunesHarmonyDaemon( QString identifier );
+    Mp3tunesHarmonyDaemon( QString identifier, int argc, char *argv[] );
     /**
      * For subsequent logins
      */
-    Mp3tunesHarmonyDaemon( QString identifier, QString email, QString pin );
+    Mp3tunesHarmonyDaemon( QString identifier, QString email, QString pin, int argc, char *argv[] );
     ~Mp3tunesHarmonyDaemon();
 
     /**
-     * Stats the daemon by intiating the connection Harmony connection.
+     * Stats the daemon by initiating the connection Harmony connection.
      */
     int init();
 
@@ -75,7 +75,7 @@ class Mp3tunesHarmonyDaemon : public QCoreApplication
 
     /**
      * The possible states the daemon can be in.
-     * Before init() it is DISONNECTED
+     * Before init() it is DISCONNECTED
      */
     enum HarmonyState {
         DISCONNECTED,
@@ -103,7 +103,7 @@ class Mp3tunesHarmonyDaemon : public QCoreApplication
     void emitDownloadReady( const Mp3tunesHarmonyDownload &download );
     void emitDownloadPending( const Mp3tunesHarmonyDownload &download );
 
-  signals:
+  Q_SIGNALS:
       /* The actual signals that get emitted */
       void waitingForEmail( const QString &pin );
       void waitingForPin();
@@ -122,7 +122,7 @@ class Mp3tunesHarmonyDaemon : public QCoreApplication
        * adding the download to its own queue
        */
       void downloadPending( const Mp3tunesHarmonyDownload &download );
-  public slots:
+  public Q_SLOTS:
       /**
      * Returns the pin
      */
