@@ -103,7 +103,7 @@ class ScriptableServiceAlbum : public Meta::ServiceAlbumWithCover, public Script
         void setCoverUrl( const QString &coverUrl ) override { m_coverUrl = coverUrl; }
         QString coverUrl() const override { return m_coverUrl; }
 
-        QUrl imageLocation( int size = 1 ) override { Q_UNUSED( size ); return QUrl( coverUrl() ); }
+        QUrl imageLocation( int size = 1 ) const override { Q_UNUSED( size ); return QUrl( coverUrl() ); }
 
         QString sourceName() override;
         QString sourceDescription() override;
