@@ -19,13 +19,10 @@
 
 #include <KPageDialog>
 
-#include <QButtonGroup>
 #include <QMap>
 #include <QSharedPointer>
 #include <QString>
 
-#include <QIcon>
-
 namespace StatSyncing
 {
 
