@@ -33,10 +33,10 @@ class SlimToolbar : public QToolBar
     Q_OBJECT
 
 public:
-    SlimToolbar( QWidget * parent );
-    ~SlimToolbar();
+    explicit SlimToolbar( QWidget * parent );
+    ~SlimToolbar() override;
 
-    virtual bool eventFilter( QObject* object, QEvent* event );
+    bool eventFilter( QObject* object, QEvent* event ) override;
 
 private:
     CurrentTrackToolbar * m_currentTrackToolbar;
